# Snakemake Interface (snakeface)

![img/snakeface.png](img/snakeface.png)

Snakeface is an interface for snakemake. If you are an individual, you can run
it locally as a notebook to run and manage workflows. If you are an institution or group,
you (will be able to) deploy a shared instance for others to use. To get started, please see
the [documentation](https://snakemake.github.io/snakeface) (not created yet).

**Snakeface is under development!** We are developing deployment types and features
as they are requested. Currently, a single user notebook deployment is supported.
Please [open an issue](https://github.com/snakemake/snakeface/issues) to request a feature, bug fix, or different deployment type.
See the [documentation](https://snakemake.github.io/snakeface/) to get started.

## Thanks

Snakeface wouldn't be possible without several open source libraries!

 - [Django](https://github.com/django/django) "The web framework for perfectionists" (and dinosaurs) 

## License

 * Free software: MPL 2.0 License

